==> haskell-language-python-0.5.4-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-python
version: 0.5.4
id: language-python-0.5.4-8lNcvpYAcXH7aPq0bQFhSG
key: language-python-0.5.4-8lNcvpYAcXH7aPq0bQFhSG
license: BSD-3-Clause
copyright: (c) 2008-2016 Bernard James Pope
maintainer: florbitous@gmail.com
author: Bernard James Pope (Bernie Pope)
stability: experimental
homepage: http://github.com/bjpop/language-python
synopsis: Parsing and pretty printing of Python code.
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.
category: Language
abi: 27d842f706d3d094fc71d79dd38c8503
exposed: True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser
hidden-modules: Language.Python.Common.ParserUtils
                Language.Python.Common.LexerUtils
                Language.Python.Version3.Parser.Parser
                Language.Python.Version3.Parser.Lexer
                Language.Python.Version2.Parser.Parser
                Language.Python.Version2.Parser.Lexer
import-dirs: /usr/lib/ghc-8.6.3/site-local/language-python-0.5.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/language-python-0.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/language-python-0.5.4
hs-libraries: HSlanguage-python-0.5.4-8lNcvpYAcXH7aPq0bQFhSG
depends:
    array-0.5.3.0 base-4.12.0.0 containers-0.6.0.1
    monads-tf-0.1.0.3-DFJmu4IXpHk2UzhiB94rsJ pretty-1.1.3.6
    transformers-0.5.5.0 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-language-python/html/language-python.haddock
haddock-html: /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-python-0.5.6-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-python
version: 0.5.6
id: language-python-0.5.6-2iHSLodrvgM5xGF6ZzjL1H
key: language-python-0.5.6-2iHSLodrvgM5xGF6ZzjL1H
license: BSD-3-Clause
copyright: (c) 2008-2019 Bernard James Pope
maintainer: florbitous@gmail.com
author: Bernard James Pope (Bernie Pope)
stability: experimental
homepage: http://github.com/bjpop/language-python
synopsis: Parsing and pretty printing of Python code.
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.
category: Language
abi: 9f7e687175d34a829fe95c1402e00707
exposed: True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser
hidden-modules: Language.Python.Common.ParserUtils
                Language.Python.Common.LexerUtils
                Language.Python.Version3.Parser.Parser
                Language.Python.Version3.Parser.Lexer
                Language.Python.Version2.Parser.Parser
                Language.Python.Version2.Parser.Lexer
import-dirs: /usr/lib/ghc-8.6.3/site-local/language-python-0.5.6
library-dirs: /usr/lib/ghc-8.6.3/site-local/language-python-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/language-python-0.5.6
hs-libraries: HSlanguage-python-0.5.6-2iHSLodrvgM5xGF6ZzjL1H
depends:
    array-0.5.3.0 base-4.12.0.0 containers-0.6.0.1
    monads-tf-0.1.0.3-DFJmu4IXpHk2UzhiB94rsJ pretty-1.1.3.6
    transformers-0.5.5.0 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-language-python/html/language-python.haddock
haddock-html: /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
